@@ -189,7 +189,8 @@ class JsonClass:
 class RegularClass:
     def __init__(self):
         pass
-
+    
+    '''数字'''
     def pInt(self, value: str, include_zero: bool = True):
         '''
         正整数
@@ -206,6 +207,16 @@ class RegularClass:
         if result:
             return True
         return False
+    
+    def zero_pint(self, val):
+        '''
+        0和正整数
+        '''
+        val = str(val)
+        result = re.match(r'^\d+$', val)
+        if result:
+            return True
+        return False
 
     def price(self, value):
         '''
